"""Module providing classes and functions for statistical analyses."""

from biopsykit.stats.stats import StatsPipeline

__all__ = ["StatsPipeline", "regression", "multicoll"]
